@@ -25,20 +25,22 @@
 #include "floppy.h"
 #include "format.h"
 
+#include <QApplication>
 #include <QCheckBox>
 #include <QLabel>
-#include <qcursor.h>
-#include <qgroupbox.h>
-#include <qradiobutton.h>
+#include <QCursor>
+#include <QGroupBox>
+#include <QRadioButton>
 #include <QVBoxLayout>
 #include <QFrame>
 #include <QHBoxLayout>
 #include <QGridLayout>
 #include <QKeyEvent>
 #include <QCloseEvent>
-#include <QtDBus/QtDBus>
+#include <QDBusInterface>
+#include <QDBusReply>
 #include <QPushButton>
-#include <qprogressbar.h>
+#include <QProgressBar>
 #include <QUrl>
 
 #include <kmessagebox.h>
@@ -57,7 +59,7 @@ Q_LOGGING_CATEGORY(KFLOPPY_LOG, "org.kde.kfloppy")
 
 FloppyData::FloppyData(QWidget * parent)
  : QDialog( parent ),
-	formatActions(0L), m_canLowLevel(false), m_canZeroOut( false )
+	formatActions(nullptr), m_canLowLevel(false), m_canZeroOut( false )
 {
 	QWidget *widget = new QWidget(this);
 	formating = false;
@@ -491,7 +493,7 @@ void FloppyData::reset()
   {
     formatActions->quit();
     delete formatActions;
-    formatActions = 0L;
+    formatActions = nullptr;
   }
 
   progress->setValue(0);
